@@ -8,6 +8,7 @@ use strict;
 use Carp;
 
 use Image::PNG::Libpng ':all';
+use Image::PNG::Const ':all';
 
 sub new
 {
@@ -45,7 +46,7 @@ sub quantize_file
 	croak "File '$in' not found";
     }
     my $out = $options{out};
-    my $inpng = read_png_file ($in);
+    my $inpng = read_png_file ($in, transforms => PNG_TRANSFORM_EXPAND);
     my $opng = $self->quantize ($inpng, %options);
     $opng->write_png_file ($out);
 }
