@@ -21,11 +21,6 @@
 #include <stdint.h>
 #include <limits.h>
 
-#if !defined(__STDC_VERSION__) || __STDC_VERSION__ < 199900L
-#error "This program requires C99, e.g. -std=c99 switch in GCC. MSVC doesn't support C newer than '89, please use MinGW on Windows."
-#error "Ignore torrent of syntax errors that may follow. It's only because compiler is set to use too old C version."
-#endif
-
 #ifdef _OPENMP
 #include <omp.h>
 #else
@@ -244,8 +239,14 @@ static double quality_to_mse(long quality)
 
 static unsigned int mse_to_quality(double mse)
 {
-    for(int i=100; i > 0; i--) {
-        if (mse <= quality_to_mse(i)) return i;
+    int i;
+    /* Allow for floating point errors. */
+    double eps = 0.00001;
+
+    for(i=100; i > 0; i--) {
+        if (mse <= quality_to_mse(i) + eps) {
+            return i;
+        }
     }
     return 0;
 }
@@ -553,7 +554,8 @@ LIQ_EXPORT liq_error liq_image_set_memory_ownership(liq_image *img, int ownershi
             // for simplicity of this API there's no explicit bitmap argument,
             // so the row with the lowest address is assumed to be at the start of the bitmap
             img->pixels = img->rows[0];
-            for(int i=1; i < img->height; i++) {
+            int i;
+            for(i=1; i < img->height; i++) {
                 img->pixels = MIN(img->pixels, img->rows[i]);
             }
         }
@@ -572,7 +574,8 @@ LIQ_EXPORT liq_image *liq_image_create_rgba_rows(liq_attr *attr, void* rows[], i
     if (width <= 0 || height <= 0) return NULL;
     if (width > INT_MAX/height/16 || height > INT_MAX/width/16) return NULL;
 
-    for(int i=0; i < height; i++) {
+    int i;
+    for(i=0; i < height; i++) {
         if (!CHECK_USER_POINTER(rows+i) || !CHECK_USER_POINTER(rows[i])) return NULL;
     }
     return liq_image_create_internal(attr, (rgba_pixel**)rows, NULL, NULL, width, height, gamma);
@@ -588,7 +591,8 @@ LIQ_EXPORT liq_error liq_image_create_rgba_rows_2 (liq_attr *attr, void* rows[],
     if (width > INT_MAX/height/16 || height > INT_MAX/width/16) {
 	return LIQ_HUGE_DIMENSIONS;
     }
-    for(int i=0; i < height; i++) {
+    int i;
+    for(i=0; i < height; i++) {
         if (!CHECK_USER_POINTER(rows+i) || !CHECK_USER_POINTER(rows[i])) {
 	    return LIQ_BAD_USER_POINTER;
 	}
@@ -608,7 +612,8 @@ LIQ_EXPORT liq_image *liq_image_create_rgba(liq_attr *attr, void* bitmap, int wi
     rgba_pixel **rows = attr->malloc(sizeof(rows[0])*height);
     if (!rows) return NULL;
 
-    for(int i=0; i < height; i++) {
+    int i;
+    for(i=0; i < height; i++) {
         rows[i] = pixels + width * i;
     }
 
@@ -656,7 +661,8 @@ static void convert_row_to_f(liq_image *img, f_pixel *row_f_pixels, const unsign
 
     const rgba_pixel *const row_pixels = liq_image_get_row_rgba(img, row);
 
-    for(unsigned int col=0; col < img->width; col++) {
+    int col;
+    for(col=0; col < img->width; col++) {
         row_f_pixels[col] = to_f(gamma_lut, row_pixels[col]);
     }
 }
@@ -683,7 +689,8 @@ static const f_pixel *liq_image_get_row_f(liq_image *img, unsigned int row)
 
         float gamma_lut[256];
         to_f_set_gamma(gamma_lut, img->gamma);
-        for(unsigned int row=0; row < img->height; row++) {
+        int row;
+        for(row=0; row < img->height; row++) {
             convert_row_to_f(img, &img->f_pixels[row*img->width], row, gamma_lut);
         }
     }
@@ -892,21 +899,24 @@ static void sort_palette(colormap *map, const liq_attr *options)
     ** the maximal alpha value (i.e., fully opaque) are at the end and can
     ** therefore be omitted from the tRNS chunk.
     */
-    if (options->last_index_transparent) for(unsigned int i=0; i < map->colors; i++) {
-        if (map->palette[i].acolor.a < 1.0/256.0) {
-            const unsigned int old = i, transparent_dest = map->colors-1;
+    if (options->last_index_transparent) {
+	int i;
+	for(i=0; i < map->colors; i++) {
+	    if (map->palette[i].acolor.a < 1.0/256.0) {
+		const unsigned int old = i, transparent_dest = map->colors-1;
 
-            SWAP_PALETTE(map, transparent_dest, old);
+		SWAP_PALETTE(map, transparent_dest, old);
 
-            /* colors sorted by popularity make pngs slightly more compressible */
-            qsort(map->palette, map->colors-1, sizeof(map->palette[0]), compare_popularity);
-            return;
+		/* colors sorted by popularity make pngs slightly more compressible */
+		qsort(map->palette, map->colors-1, sizeof(map->palette[0]), compare_popularity);
+		return;
             }
         }
-
+    }
     /* move transparent colors to the beginning to shrink trns chunk */
     unsigned int num_transparent=0;
-    for(unsigned int i=0; i < map->colors; i++) {
+    int i;
+    for(i=0; i < map->colors; i++) {
         if (map->palette[i].acolor.a < 255.0/256.0) {
             // current transparent color is swapped with earlier opaque one
             if (i != num_transparent) {
@@ -944,7 +954,8 @@ static void set_rounded_palette(liq_palette *const dest, colormap *const map, co
     to_f_set_gamma(gamma_lut, gamma);
 
     dest->count = map->colors;
-    for(unsigned int x = 0; x < map->colors; ++x) {
+    int x;
+    for(x = 0; x < map->colors; ++x) {
         rgba_pixel px = to_rgb(gamma, map->palette[x].acolor);
 
         px.r = posterize_channel(px.r, posterize);
@@ -993,10 +1004,12 @@ static float remap_to_palette(liq_image *const input_image, unsigned char *const
     #pragma omp parallel for if (rows*cols > 3000) \
         default(none) shared(average_color) reduction(+:remapping_error)
 #endif /* def _OPENMP */
-    for(int row = 0; row < rows; ++row) {
+    int row;
+    for(row = 0; row < rows; ++row) {
         const f_pixel *const row_pixels = liq_image_get_row_f(input_image, row);
         unsigned int last_match=0;
-        for(unsigned int col = 0; col < cols; ++col) {
+        int col;
+        for(col = 0; col < cols; ++col) {
             f_pixel px = row_pixels[col];
             float diff;
 
@@ -1076,7 +1089,8 @@ static void remap_to_palette_floyd(liq_image *input_image, unsigned char *const
     srand(12345); /* deterministic dithering is better for comparing results */
     if (!thiserr) return;
 
-    for (unsigned int col = 0; col < cols + 2; ++col) {
+    int col;
+    for (col = 0; col < cols + 2; ++col) {
         const double rand_max = RAND_MAX;
         thiserr[col].r = ((double)rand() - rand_max/2.0)/rand_max/255.0;
         thiserr[col].g = ((double)rand() - rand_max/2.0)/rand_max/255.0;
@@ -1094,7 +1108,8 @@ static void remap_to_palette_floyd(liq_image *input_image, unsigned char *const
 
     bool fs_direction = true;
     unsigned int last_match=0;
-    for (unsigned int row = 0; row < rows; ++row) {
+    int row;
+    for (row = 0; row < rows; ++row) {
         memset(nexterr, 0, (cols + 2) * sizeof(*nexterr));
 
         unsigned int col = (fs_direction) ? 0 : (cols - 1);
@@ -1221,7 +1236,8 @@ static histogram *get_histogram(liq_image *input_image, liq_attr *options)
 
         // histogram uses noise contrast map for importance. Color accuracy in noisy areas is not very important.
         // noise map does not include edges to avoid ruining anti-aliasing
-        for(unsigned int row=0; row < rows; row++) {
+        int row;
+        for(row=0; row < rows; row++) {
             bool added_ok;
             if (all_rows_at_once) {
                 added_ok = pam_computeacolorhash(acht, (const rgba_pixel *const *)input_image->rows, cols, rows, input_image->noise);
@@ -1272,7 +1288,8 @@ static void modify_alpha(liq_image *input_image, rgba_pixel *const row_pixels)
     const float almost_opaque_val = min_opaque_val * 169.f/256.f;
     const unsigned int almost_opaque_val_int = (min_opaque_val * 169.f/256.f)*255.f;
 
-    for(unsigned int col = 0; col < input_image->width; col++) {
+    int col;
+    for(col = 0; col < input_image->width; col++) {
         const rgba_pixel px = row_pixels[col];
 
         /* ie bug: to avoid visible step caused by forced opaqueness, linearily raise opaqueness of almost-opaque colors */
@@ -1304,13 +1321,15 @@ static void contrast_maps(liq_image *image)
     const f_pixel *curr_row, *prev_row, *next_row;
     curr_row = prev_row = next_row = liq_image_get_row_f(image, 0);
 
-    for (unsigned int j=0; j < rows; j++) {
+    int j;
+    for (j=0; j < rows; j++) {
         prev_row = curr_row;
         curr_row = next_row;
         next_row = liq_image_get_row_f(image, MIN(rows-1,j+1));
 
         f_pixel prev, curr = curr_row[0], next=curr;
-        for (unsigned int i=0; i < cols; i++) {
+        int i;
+        for (i=0; i < cols; i++) {
             prev=curr;
             curr=next;
             next = curr_row[MIN(cols-1,i+1)];
@@ -1358,7 +1377,8 @@ static void contrast_maps(liq_image *image)
 
     min3(edges, tmp, cols, rows);
     max3(tmp, edges, cols, rows);
-    for(unsigned int i=0; i < cols*rows; i++) edges[i] = MIN(noise[i], edges[i]);
+    int i;
+    for(i=0; i < cols*rows; i++) edges[i] = MIN(noise[i], edges[i]);
 
     image->free(tmp);
 
@@ -1379,11 +1399,13 @@ static void update_dither_map(unsigned char *const *const row_pointers, liq_imag
     const unsigned int height = input_image->height;
     unsigned char *const edges = input_image->edges;
 
-    for(unsigned int row=0; row < height; row++) {
+    int row;
+    for(row=0; row < height; row++) {
         unsigned char lastpixel = row_pointers[row][0];
         unsigned int lastcol=0;
 
-        for(unsigned int col=1; col < width; col++) {
+        int col;
+        for(col=1; col < width; col++) {
             const unsigned char px = row_pointers[row][col];
 
             if (px != lastpixel || col == width-1) {
@@ -1470,7 +1492,8 @@ static colormap *find_best_palette(histogram *hist, const liq_attr *options, dou
 
             feedback_loop_trials -= 1; // asymptotic improvement could make it go on forever
         } else {
-            for(unsigned int j=0; j < hist->size; j++) {
+            int j;
+            for(j=0; j < hist->size; j++) {
                 hist->achv[j].adjusted_weight = (hist->achv[j].perceptual_weight + hist->achv[j].adjusted_weight)/2.0;
             }
 
@@ -1486,12 +1509,14 @@ static colormap *find_best_palette(histogram *hist, const liq_attr *options, dou
     while(feedback_loop_trials > 0);
 
     // likely_colormap_index (used and set in viter_do_iteration) can't point to index outside colormap
-    if (acolormap->colors < 256) for(unsigned int j=0; j < hist->size; j++) {
-        if (hist->achv[j].likely_colormap_index >= acolormap->colors) {
-            hist->achv[j].likely_colormap_index = 0; // actual value doesn't matter, as the guess is out of date anyway
-        }
+    if (acolormap->colors < 256) {
+	int j;
+	for(j=0; j < hist->size; j++) {
+	    if (hist->achv[j].likely_colormap_index >= acolormap->colors) {
+		hist->achv[j].likely_colormap_index = 0; // actual value doesn't matter, as the guess is out of date anyway
+	    }
+	}
     }
-
     *palette_error_p = least_error;
     return acolormap;
 }
@@ -1505,7 +1530,8 @@ static liq_result *pngquant_quantize(histogram *hist, const liq_attr *options, c
     // then it's possible to skip quantization entirely
     if (hist->size <= options->max_colors && options->target_mse == 0) {
         acolormap = pam_colormap(hist->size);
-        for(unsigned int i=0; i < hist->size; i++) {
+        int i;
+        for(i=0; i < hist->size; i++) {
             acolormap->palette[i].acolor = hist->achv[i].acolor;
             acolormap->palette[i].popularity = hist->achv[i].perceptual_weight;
         }
@@ -1525,7 +1551,8 @@ static liq_result *pngquant_quantize(histogram *hist, const liq_attr *options, c
 
             double previous_palette_error = MAX_DIFF;
 
-            for(unsigned int i=0; i < iterations; i++) {
+            int i;
+            for(i=0; i < iterations; i++) {
                 palette_error = viter_do_iteration(hist, acolormap, options->min_opaque_val, NULL, i==0 || options->fast_palette);
 
                 if (fabs(previous_palette_error-palette_error) < iteration_limit) {
@@ -1581,7 +1608,8 @@ LIQ_EXPORT liq_error liq_write_remapped_image(liq_result *result, liq_image *inp
 
     unsigned char *rows[input_image->height];
     unsigned char *buffer_bytes = buffer;
-    for(unsigned int i=0; i < input_image->height; i++) {
+    int i;
+    for(i=0; i < input_image->height; i++) {
         rows[i] = &buffer_bytes[input_image->width * i];
     }
     return liq_write_remapped_image_rows(result, input_image, rows);
@@ -1591,7 +1619,8 @@ LIQ_EXPORT liq_error liq_write_remapped_image_rows(liq_result *quant, liq_image
 {
     if (!CHECK_STRUCT_TYPE(quant, liq_result)) return LIQ_INVALID_POINTER;
     if (!CHECK_STRUCT_TYPE(input_image, liq_image)) return LIQ_INVALID_POINTER;
-    for(int i=0; i < input_image->height; i++) {
+    int i;
+    for(i=0; i < input_image->height; i++) {
         if (!CHECK_USER_POINTER(row_pointers+i) || !CHECK_USER_POINTER(row_pointers[i])) return LIQ_INVALID_POINTER;
     }
 
