@@ -267,7 +267,7 @@ inline static double color_weight(f_pixel median, hist_item h)
     return sqrt(diff) * (sqrt(1.0+h.adjusted_weight)-1.0);
 }
 
-static void set_colormap_from_boxes(colormap *map, struct box* bv, unsigned int boxes, hist_item *achv);
+static colormap *colormap_from_boxes(struct box* bv, unsigned int boxes, hist_item *achv);
 static void adjust_histogram(hist_item *achv, const colormap *map, const struct box* bv, unsigned int boxes);
 
 double box_error(const struct box *box, const hist_item achv[])
@@ -314,7 +314,7 @@ static bool total_box_error_below_target(double target_mse, struct box bv[], uns
  ** on Paul Heckbert's paper, "Color Image Quantization for Frame Buffer
  ** Display," SIGGRAPH 1982 Proceedings, page 297.
  */
-LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, unsigned int newcolors, const double target_mse, const double max_mse, void* (*malloc)(size_t), void (*free)(void*))
+LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, unsigned int newcolors, const double target_mse, const double max_mse)
 {
     hist_item *achv = hist->achv;
     struct box bv[newcolors];
@@ -344,8 +344,7 @@ LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, uns
     while (boxes < newcolors) {
 
         if (boxes == subset_size) {
-            representative_subset = pam_colormap(boxes, malloc, free);
-            set_colormap_from_boxes(representative_subset, bv, boxes, achv);
+            representative_subset = colormap_from_boxes(bv, boxes, achv);
         }
 
         // first splits boxes that exceed quality limit (to have colors for things like odd green pixel),
@@ -407,16 +406,14 @@ LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, uns
         }
     }
 
-    colormap *map = pam_colormap(boxes, malloc, free);
-    set_colormap_from_boxes(map, bv, boxes, achv);
-
+    colormap *map = colormap_from_boxes(bv, boxes, achv);
     map->subset_palette = representative_subset;
     adjust_histogram(achv, map, bv, boxes);
 
     return map;
 }
 
-static void set_colormap_from_boxes(colormap *map, struct box* bv, unsigned int boxes, hist_item *achv)
+static colormap *colormap_from_boxes(struct box* bv, unsigned int boxes, hist_item *achv)
 {
     /*
      ** Ok, we've got enough boxes.  Now choose a representative color for
@@ -426,6 +423,8 @@ static void set_colormap_from_boxes(colormap *map, struct box* bv, unsigned int
      ** the box - this is the method specified in Heckbert's paper.
      */
 
+    colormap *map = pam_colormap(boxes);
+
     int bi;
     for(bi = 0; bi < boxes; ++bi) {
         map->palette[bi].acolor = bv[bi].color;
@@ -437,6 +436,8 @@ static void set_colormap_from_boxes(colormap *map, struct box* bv, unsigned int
             map->palette[bi].popularity += achv[i].perceptual_weight;
         }
     }
+
+    return map;
 }
 
 /* increase histogram popularity by difference from the final color (this is used as part of feedback loop) */
